==> material-react-table-1.2.1.tgz: package/src/_locales/cs.ts <==
import { MRT_Localization } from '../MaterialReactTable';

export const MRT_Localization_CS: MRT_Localization = {
  actions: 'Akce',
  and: 'a',
  cancel: 'Zrušit',
  changeFilterMode: 'Změnit režim filtru',
  changeSearchMode: 'Změnit režim hledání',
  clearFilter: 'Vyčistit filtr',
  clearSearch: 'Vyčistit hledání',
  clearSort: 'vyčistit řazení',
  clickToCopy: 'Kliknutím zkopírovat',
  columnActions: 'Akce sloupce',
  copiedToClipboard: 'Zkopírovat do schránky',
  dropToGroupBy: 'Upustit pro seskupení podle sloupce {column}',
  edit: 'Upravit',
  expand: 'Otevřít',
  expandAll: 'Otevřít vše',
  filterArrIncludes: 'Obsahuje',
  filterArrIncludesAll: 'Obsahuje všechno',
  filterArrIncludesSome: 'Obsahuje některé',
  filterBetween: 'Mezi',
  filterBetweenInclusive: 'Mezi',
  filterByColumn: 'Filtrovat podle sloupce {column}',
  filterContains: 'Obsahuje',
  filterEmpty: 'Prázdné',
  filterEndsWith: 'Končí na',
  filterEquals: 'Rovná se',
  filterEqualsString: 'Rovná se',
  filterFuzzy: 'Podobné',
  filterGreaterThan: 'Větší než',
  filterGreaterThanOrEqualTo: 'Větší nebo rovno',
  filterInNumberRange: 'Mezi',
  filterIncludesString: 'Obsahuje',
  filterIncludesStringSensitive: 'Obsahuje',
  filterLessThan: 'Menší než',
  filterLessThanOrEqualTo: 'Menší nebo rovno',
  filterMode: 'Režim filtru: {filterType}',
  filterNotEmpty: 'Není prázdné',
  filterNotEquals: 'Nerovná se',
  filterStartsWith: 'Začíná na',
  filterWeakEquals: 'Rovná se',
  filteringByColumn: 'Filtrováno podle sloupce {column} - {filterType} {filterValue}',
  goToFirstPage: 'První strana',
  goToLastPage: 'Poslední strana',
  goToNextPage: 'Další strana',
  goToPreviousPage: 'Předchozí strana',
  grab: 'Chytit',
  groupByColumn: 'Seskupit podle sloupce {column}',
  groupedBy: 'Seskupeno podle ',
  hideAll: 'Skrýt vše',
  hideColumn: 'Skrýt sloupec {column}',
  max: 'Max.',
  min: 'Min.',
  move: 'Přesunout',
  noRecordsToDisplay: 'Žádné záznamy k zobrazení',
  noResultsFound: 'Nenalezeny žádné výsledky',
  of: 'z',
  or: 'nebo',
  pinToLeft: 'Připnout doleva',
  pinToRight: 'Připnout doprava',
  resetColumnSize: 'Resetovat šířku sloupců',
  resetOrder: 'Resetovat pořadí',
  rowActions: 'Akce řádky',
  rowNumber: '#',
  rowNumbers: 'Čísla řádek',
  rowsPerPage: 'Řádek na stránce',
  save: 'Uložit',
  search: 'Hledat',
  selectedCountOfRowCountRowsSelected: 'Vybráno {selectedCount} z {rowCount} řádek',
  select: 'Vybrat',
  showAll: 'Zobrazit vše',
  showAllColumns: 'Zobrazit všechny sloupce',
  showHideColumns: 'Zobrazit/Skrýt sloupce',
  showHideFilters: 'Zobrazit/Skrýt filtry',
  showHideSearch: 'Zobrazit/Skrýt hledání',
  sortByColumnAsc: 'Seřadit podle sloupce {column} vzestupně',
  sortByColumnDesc: 'Seřadit podle sloupce {column} sestupně',
  sortedByColumnAsc: 'Seřazeno podle sloupce {column} vzestupně',
  sortedByColumnDesc: 'Seřazeno podle sloupce {column} sestupně',
  thenBy: ', pak podle ',
  toggleDensity: 'Změnit hustotu řádek',
  toggleFullScreen: 'Zobrazení na celou stránku',
  toggleSelectAll: 'Vybrat vše',
  toggleSelectRow: 'Vybrat řádku',
  toggleVisibility: 'Zobrazení',
  ungroupByColumn: 'Neseskupovat podle sloupce {column}',
  unpin: 'Odepnout',
  unpinAll: 'Odepnout vše',
  unsorted: 'Neseřazeno',
};

==> material-react-table-1.2.7.tgz: package/src/_locales/cs.ts <==
import { MRT_Localization } from '../MaterialReactTable';

export const MRT_Localization_CS: MRT_Localization = {
  actions: 'Akce',
  and: 'a',
  cancel: 'Zrušit',
  changeFilterMode: 'Změnit režim filtru',
  changeSearchMode: 'Změnit režim hledání',
  clearFilter: 'Vyčistit filtr',
  clearSearch: 'Vyčistit hledání',
  clearSort: 'vyčistit řazení',
  clickToCopy: 'Kliknutím zkopírovat',
  columnActions: 'Akce sloupce',
  copiedToClipboard: 'Zkopírovat do schránky',
  dropToGroupBy: 'Upustit pro seskupení podle sloupce {column}',
  edit: 'Upravit',
  expand: 'Otevřít',
  expandAll: 'Otevřít vše',
  filterArrIncludes: 'Obsahuje',
  filterArrIncludesAll: 'Obsahuje všechno',
  filterArrIncludesSome: 'Obsahuje některé',
  filterBetween: 'Mezi',
  filterBetweenInclusive: 'Mezi',
  filterByColumn: 'Filtrovat podle sloupce {column}',
  filterContains: 'Obsahuje',
  filterEmpty: 'Prázdné',
  filterEndsWith: 'Končí na',
  filterEquals: 'Rovná se',
  filterEqualsString: 'Rovná se',
  filterFuzzy: 'Podobné',
  filterGreaterThan: 'Větší než',
  filterGreaterThanOrEqualTo: 'Větší nebo rovno',
  filterInNumberRange: 'Mezi',
  filterIncludesString: 'Obsahuje',
  filterIncludesStringSensitive: 'Obsahuje',
  filterLessThan: 'Menší než',
  filterLessThanOrEqualTo: 'Menší nebo rovno',
  filterMode: 'Režim filtru: {filterType}',
  filterNotEmpty: 'Není prázdné',
  filterNotEquals: 'Nerovná se',
  filterStartsWith: 'Začíná na',
  filterWeakEquals: 'Rovná se',
  filteringByColumn:
    'Filtrováno podle sloupce {column} - {filterType} {filterValue}',
  goToFirstPage: 'První strana',
  goToLastPage: 'Poslední strana',
  goToNextPage: 'Další strana',
  goToPreviousPage: 'Předchozí strana',
  grab: 'Chytit',
  groupByColumn: 'Seskupit podle sloupce {column}',
  groupedBy: 'Seskupeno podle ',
  hideAll: 'Skrýt vše',
  hideColumn: 'Skrýt sloupec {column}',
  max: 'Max.',
  min: 'Min.',
  move: 'Přesunout',
  noRecordsToDisplay: 'Žádné záznamy k zobrazení',
  noResultsFound: 'Nenalezeny žádné výsledky',
  of: 'z',
  or: 'nebo',
  pinToLeft: 'Připnout doleva',
  pinToRight: 'Připnout doprava',
  resetColumnSize: 'Resetovat šířku sloupců',
  resetOrder: 'Resetovat pořadí',
  rowActions: 'Akce řádky',
  rowNumber: '#',
  rowNumbers: 'Čísla řádek',
  rowsPerPage: 'Řádek na stránce',
  save: 'Uložit',
  search: 'Hledat',
  selectedCountOfRowCountRowsSelected:
    'Vybráno {selectedCount} z {rowCount} řádek',
  select: 'Vybrat',
  showAll: 'Zobrazit vše',
  showAllColumns: 'Zobrazit všechny sloupce',
  showHideColumns: 'Zobrazit/Skrýt sloupce',
  showHideFilters: 'Zobrazit/Skrýt filtry',
  showHideSearch: 'Zobrazit/Skrýt hledání',
  sortByColumnAsc: 'Seřadit podle sloupce {column} vzestupně',
  sortByColumnDesc: 'Seřadit podle sloupce {column} sestupně',
  sortedByColumnAsc: 'Seřazeno podle sloupce {column} vzestupně',
  sortedByColumnDesc: 'Seřazeno podle sloupce {column} sestupně',
  thenBy: ', pak podle ',
  toggleDensity: 'Změnit hustotu řádek',
  toggleFullScreen: 'Zobrazení na celou stránku',
  toggleSelectAll: 'Vybrat vše',
  toggleSelectRow: 'Vybrat řádku',
  toggleVisibility: 'Zobrazení',
  ungroupByColumn: 'Neseskupovat podle sloupce {column}',
  unpin: 'Odepnout',
  unpinAll: 'Odepnout vše',
  unsorted: 'Neseřazeno',
};
